#  Copyright 2017 Patrick O. Perry.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


text_ntype <- function(x, filter = text_filter(x), collapse = FALSE)
{
    with_rethrow({
        x <- as_text(x, filter = filter)
        collapse <- as_option("collapse", collapse)
    })
    .Call(C_text_ntype, x, collapse)
}


text_types <- function(x, filter = text_filter(x), collapse = FALSE)
{
    with_rethrow({
        x <- as_text(x, filter = filter)
        collapse <- as_option("collapse", collapse)
    })
    typs <- .Call(C_text_types, x, collapse)
    if (collapse) {
        typs <- sort(typs)
    } else {
        typs <- lapply(typs, sort)
    }
    typs
}
